@@ -7,9 +7,9 @@
 #' @param output Output object from the easybgm function. Supports also objects from the bgm function of the `bgms` package.
 #' @param as_BF If TRUE plots the y-axis as Bayes factors instead of posterior structure probability. Default is FALSE.
 #' @param ... Additional arguments passed onto `ggplot2`
-#' 
+#'
 #' @return Returns a plot
-#' 
+#'
 #' @export
 #' @importFrom dplyr group_by summarise mutate group_modify filter
 #'
@@ -21,20 +21,18 @@
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "ordinal", save = TRUE, edge_selection = TRUE,
-#'                 iter = 1000  # for demonstration only (> 5e4 recommended)
+#'                 iter = 100  # for demonstration only (> 5e4 recommended)
 #'                 )
 #'
 #' plot_structure_probabilities(fit)
 #' }
 
 plot_structure_probabilities <- function(output, as_BF = FALSE, ...) {
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
+
   UseMethod("plot_structure_probabilities", output)
 
 }
@@ -50,9 +48,9 @@ plot_structure_probabilities <- function(output, as_BF = FALSE, ...) {
 #'
 #' @param output Output object from the easybgm function. Supports also objects from the bgm function of the `bgms` package.
 #' @param ... Additional arguments passed onto `ggplot2`
-#' 
+#'
 #' @return Returns a plot
-#' 
+#'
 #' @export
 #' @import ggplot2
 #'
@@ -64,20 +62,17 @@ plot_structure_probabilities <- function(output, as_BF = FALSE, ...) {
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "ordinal", save = TRUE, edge_selection = TRUE,
-#'                 iter = 1000  # for demonstration only (> 5e4 recommended)
+#'                 iter = 100  # for demonstration only (> 5e4 recommended)
 #'                 )
 #'
 #' plot_complexity_probabilities(fit)
 #' }
 
 plot_complexity_probabilities <- function(output, ...) {
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
   UseMethod("plot_complexity_probabilities", output)
 
 }
@@ -86,12 +81,17 @@ plot_complexity_probabilities <- function(output, ...) {
 
 #' @title Edge evidence plot
 #'
-#' @description The edge evidence plot colors edges according to their hypothesis testing results: blue for included, red for excluded, and gray for inconclusive. This plot can be used to visualize the hypothesis testing results whether edge presence or absence. The edge evidence plot can aid researchers in deciding which edges provide robust inferential conclusions
+#' @description The edge evidence plot colors edges according to their hypothesis testing results: blue for included,
+#'    light blue for weakly included, gray for inconclusive, light yellow for weakly excluded, and yellow for excluded.
+#'    This plot can be used to visualize the hypothesis testing results whether edge presence or absence. The edge evidence
+#'    plot can aid researchers in deciding which edges provide robust inferential conclusions
 #'
 #' @name edgeevidence
 #'
 #' @param output Output object from the easybgm function. Supports also objects from the bgm function of the `bgms` package.
-#' @param evidence_thresh Bayes Factor which will be considered sufficient evidence for in-/exclusion, default is 10.
+#' @param evidence_thresh Bayes Factor which will be considered sufficient evidence for in-/exclusion, default is 10. Note that
+#'    this parameter defines when edges provide sufficient evidence, thus when the edge color will turn saturated blue or yellow.
+#'    All edges with a BF between 3 and the evidence threshold will receive a light saturated edge color.
 #' @param split if TRUE, plot is split in included and excluded edges. Note that by default separate plots are shown and appear after each other in the plot window. To show the plots side-by-side specify par(mfrow = c(1, 2)).
 #' @param show specifies which edges should be shown, indicated by "all", "included", "inconclusive", "excluded".
 #' @param ... Additional arguments passed onto `qgraph`.
@@ -107,13 +107,13 @@ plot_complexity_probabilities <- function(output, ...) {
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "continuous",
-#'                 iter = 1000  # for demonstration only (> 5e4 recommended)
+#'                 iter = 100  # for demonstration only (> 5e4 recommended)
 #'                 )
 #'
 #' plot_edgeevidence(fit)
 #'
 #' oldpar <- par(mfrow = c(1,1))
-#' 
+#'
 #' par(mfrow = c(1, 2))
 #' plot_edgeevidence(fit, split = TRUE)
 #'
@@ -121,19 +121,16 @@ plot_complexity_probabilities <- function(output, ...) {
 #' plot_edgeevidence(fit, show = "included")
 #' plot_edgeevidence(fit, show = "inconclusive")
 #' plot_edgeevidence(fit, show = "excluded")
-#' 
+#'
 #' par(oldpar)
 #' }
 
 
 plot_edgeevidence <- function(output, evidence_thresh = 10, split = FALSE, show = "all",...) {
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
 
   UseMethod("plot_edgeevidence", output)
 
@@ -153,7 +150,7 @@ plot_edgeevidence <- function(output, evidence_thresh = 10, split = FALSE, show
 #' @param dashed A binary parameter indicating whether edges with inconclusive evidence should be dashed. Default is FALSE
 #' @param evidence_thresh If dashed = TRUE, users can specify the threshold for sufficient evidence for inclusion. All edges with evidence lower than `evidence_tresh` are dashed.
 #' @param ... Additional arguments passed onto `qgraph`.
-#' 
+#'
 #' @return Returns a plot
 #'
 #' @export
@@ -165,7 +162,7 @@ plot_edgeevidence <- function(output, evidence_thresh = 10, split = FALSE, show
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "continuous",
-#'                 iter = 1000  # for demonstration only (> 5e4 recommended)
+#'                 iter = 100  # for demonstration only (> 5e4 recommended)
 #'                 )
 #'
 #' plot_network(fit)
@@ -175,17 +172,14 @@ plot_edgeevidence <- function(output, evidence_thresh = 10, split = FALSE, show
 #'
 #' # Indicate which edges have insufficient evidence for inclusion through a dashed line
 #' plot_network(fit, dashed = TRUE, evidence_thresh = 10)
-#' 
+#'
 
 plot_network <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = FALSE, ...) {
 
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
   UseMethod("plot_network", output)
 
 }
@@ -203,7 +197,7 @@ plot_network <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = F
 #' @param ... Additional arguments passed onto `qgraph`
 #'
 #' @return Returns a plot
-#' 
+#'
 #' @export
 #'
 #' @import qgraph
@@ -216,20 +210,17 @@ plot_network <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = F
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "ordinal",
-#'                 iter = 1000  # for demonstration only (> 5e4 recommended)
+#'                 iter = 100  # for demonstration only (> 5e4 recommended)
 #'                )
 #'
 #' plot_structure(fit)
 #' }
 
 plot_structure <- function(output, ...) {
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
   UseMethod("plot_structure", output)
 
 }
@@ -248,7 +239,7 @@ plot_structure <- function(output, ...) {
 #' @param ... Additional arguments passed onto `ggplot2`
 #'
 #' @return Returns a plot
-#' 
+#'
 #' @export
 #' @import ggplot2 HDInterval
 #' @importFrom stats median
@@ -261,21 +252,19 @@ plot_structure <- function(output, ...) {
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "ordinal",
-#'               iter = 1000,  # for demonstration only (> 5e4 recommended)
-#'               save = TRUE, edge_selection = TRUE)
+#'               iter = 100,  # for demonstration only (> 5e4 recommended)
+#'               edge_selection = TRUE, save = TRUE)
 #' plot_parameterHDI(fit)
 #' }
 
 
 
 plot_parameterHDI <- function(output, ...) {
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
+
   UseMethod("plot_parameterHDI", output)
 
 }
@@ -289,38 +278,37 @@ plot_parameterHDI <- function(output, ...) {
 #'
 #' @name centrality
 #'
-#' @param output Output object from the easybgm function. Supports also objects from the bgm function of the `bgms` package.
+#' @param output One output object or a list of several output objects from the easybgm function. Supports also objects from the bgm function of the `bgms` package.
+#' @param group_names Specifying the group names, when providing a list of output objects. Needs to be a vector in the same length as the provided number of objects.
 #' @param ... Additional arguments passed onto `ggplot2`
 #'
 #' @return Returns a plot
-#' 
+#'
 #' @importFrom dplyr arrange
+#' @importFrom dplyr pull
 #' @importFrom ggplot2 .data
 #' @export
 #'
 #' @examples
+#' 
 #' \donttest{
-#'
 #' library(easybgm)
 #' library(bgms)
 #'
 #' data <- na.omit(Wenchuan)
 #' fit <- easybgm(data, type = "ordinal",
-#'                 iter = 1000,  # for demonstration only (> 5e4 recommended)
-#'                 save = TRUE, edge_selection = TRUE,
+#'                 iter = 100,  # for demonstration only (> 5e4 recommended)
+#'                 edge_selection = TRUE, save = TRUE, 
 #'                 centrality = TRUE)
 #'
 #' plot_centrality(fit)
 #' }
 
-plot_centrality <- function(output, ...){
-  if(any(any(class(output) == "easybgm"), any(class(output) == "bgms")) == FALSE){
+plot_centrality <- function(output, group_names = NULL, ...){
+  if(any(any(class(output) == "easybgm"), any(class(output) == "list"), any(class(output) == "bgms"), any(class(output) == "bgmCompare")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
 
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
   UseMethod("plot_centrality", output)
 
 }
@@ -330,46 +318,42 @@ plot_centrality <- function(output, ...){
 #' @title Plot sensitivity to edge inclusion prior setting
 #' @description For a given list of easybgm outputs with different prior edge inclusion probabilities, the function
 #'  plots the percentage of edges that are included, excluded, and inconclusive.
-#' @name prior_sensitivity 
+#' @name prior_sensitivity
 #' @param output A list of easybgm outputs with different prior edge inclusion probabilities
 #' @param ... Additional arguments passed onto ggplot2.
 #'
 #' @return Returns a plot
-#' 
-#' @export 
+#'
+#' @export
 #'
 #' @examples
+#' 
 #' \donttest{
-#'
 #' library(easybgm)
 #' library(bgms)
 #'
 #' #data <- na.omit(Wenchuan)
 #' #fit1 <- easybgm(data, type = "ordinal",
-#' #               iter = 1000  # for demonstration only (> 5e4 recommended),
+#' #               iter = 100  # for demonstration only (> 5e4 recommended),
 #' #                inclusion_probability = .1
 #' #               )
 #' #fit2 <- easybgm(data, type = "ordinal",
-#' #                  iter = 1000,
+#' #                  iter = 100,
 #' #                  inclusion_probability = .5
 #' #             )
 #' #fit3 <- easybgm(data, type = "ordinal",
-#' #                iter = 1000, inclusion_probability = .9)              
-#' 
+#' #                iter = 100, inclusion_probability = .9)
+#'
 #' #plot_prior_sensitivity(list(fit1, fit2, fit3))
 #' }
 
 plot_prior_sensitivity <- function(output, ...) {
   if (!is.list(output))
-    stop("Wrong input provided. Please provide a list of outputs of the easybgm function.")
+    stop("Wrong input provided. Please provide a list of outputs of the easybgm or bgms function.")
   if(any(any(class(output[[1]]) == "easybgm"), any(class(output[[1]]) == "bgms")) == FALSE){
     stop("Wrong input provided. The function requires as input the output of the easybgm or bgm function.")
   }
-  
-  if(any(class(output)=="bgms") & (packageVersion("bgms") < "0.1.1")){
-    stop("The fit of this version of bgms is not compatible with the plot. Please install the latest package version and refit the data.")
-  }
-  
+
   UseMethod("plot_prior_sensitivity", output)
 }
 
