@@ -1,17 +1,22 @@
 #' @export
 
 plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
   
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
+  
   # Give error if save is false
   if(fit_args$save == FALSE){
     stop("The plot cannot be obtained for this model fit as the posterior samples weren't stored. Rerun the model fit and set 'save = TRUE'.")
   }
   
+  
   # Extract the results from bgms
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -21,6 +26,7 @@ plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
                                   beta_bernoulli_beta = fit_args$beta_bernoulli_beta)
   output <- res
   
+  
   # Specify default arguments for function
   default_args <- list(
     xlab = "Structures",
@@ -80,17 +86,21 @@ plot_structure_probabilities.bgms <- function(output, as_BF = FALSE, ...) {
 
 plot_complexity_probabilities.bgms <- function(output, ...) {
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
   
   # Give error if save is false
   if(fit_args$save == FALSE){
     stop("The plot cannot be obtained for this model fit as the posterior samples weren't stored. Rerun the model fit and set 'save = TRUE'.")
   }
   
+  
   # Extract the results from bgms
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -121,10 +131,22 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
     complexity[i] <- sum(as.numeric(unlist(strsplit(output$sample_graph[i], ""))))
   }
   
-  data_complexity <- data.frame(complexity = complexity, weights = output$graph_weights) |>
-    dplyr::group_by(complexity) |>
-    dplyr::summarise(complexity_weight = sum(.data$weights)) |>
-    dplyr::mutate(complexity_weight = .data$complexity_weight/sum(.data$complexity_weight))
+  data_complexity <- data.frame(
+    complexity = complexity,
+    weights = output$graph_weights
+  )
+  
+  data_complexity <- dplyr::group_by(data_complexity, complexity)
+  
+  data_complexity <- dplyr::summarise(
+    data_complexity,
+    complexity_weight = sum(.data$weights)
+  )
+  
+  data_complexity <- dplyr::mutate(
+    data_complexity,
+    complexity_weight = .data$complexity_weight / sum(.data$complexity_weight)
+  )
   
   ggplot(data_complexity, aes(x = .data$complexity, y = .data$complexity_weight, ...)) +
     geom_point(size = 3) +
@@ -148,16 +170,16 @@ plot_complexity_probabilities.bgms <- function(output, ...) {
 
 plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE, show = "all", ...) {
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
-  
-  if(!fit_args$edge_selection){
-    stop("The plot cannot be obtained for this model fit as no posterior edge inclusion probabilities were obtained. Rerun the model fit and set 'edge_selection = TRUE'.")
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
   }
   
+  
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
                                   edge_prior = fit_args$edge_prior,
@@ -167,9 +189,10 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
   
   output <- res
   
+  
   # Specify default arguments for function
   default_args <- list(
-    colors = c("#36648b", "#990000", "#bfbfbf"),
+    edge.color = c("#36648b","#86a2b9", "#bfbfbf", "#f9d183", "#eeb004"),
     colnames = colnames(output$parameters),
     layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
     theme = "TeamFortress",
@@ -187,9 +210,16 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
   
   # assign a color to each edge (inclusion - blue, exclusion - red, no conclusion - grey)
   graph_color <- graph
-  graph_color <-  ifelse(graph < evidence_thresh & graph > 1/evidence_thresh,
-                         graph_color <- args$colors[3], graph_color <- args$colors[1])
-  graph_color[graph < (1/evidence_thresh)] <- args$colors[2]
+  # 1. Most evidence for inclusion
+  graph_color[graph > evidence_thresh] <- args$edge.color[1]
+  # 2. Moderate inclusion (BF > 3 but ≤ evidence_thresh)
+  graph_color[graph > 3 & graph <= evidence_thresh] <- args$edge.color[2]
+  # 3. Inconclusive (BF between 1/3 and 3)
+  graph_color[graph >= 1/3 & graph <= 3] <- args$edge.color[3]
+  # 4. Moderate exclusion (BF < 1/3 but > 1/evidence_thresh)
+  graph_color[graph < 1/3 & graph > 1/evidence_thresh] <- args$edge.color[4]
+  # 5. Strong evidence for exclusion (BF ≤ 1/evidence_thresh)
+  graph_color[graph <= 1/evidence_thresh] <- args$edge.color[5]
   
   if (show == "all") {
     if (!split) {
@@ -287,11 +317,16 @@ plot_edgeevidence.bgms <- function(output, evidence_thresh = 10, split = FALSE,
 
 plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashed = TRUE, ...) {
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
+  
+  
   
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -302,6 +337,7 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
   
   output <- res
   
+  
   if(is.null(output$inc_probs)){
     dashed <- FALSE
     warning("The model was fitted without edge selection and no inclusion probabilities were obtained. Therefore, edges cannot be dashed according to their PIP.",
@@ -352,11 +388,15 @@ plot_network.bgms <- function(output, exc_prob = .5, evidence_thresh = 10, dashe
 
 plot_structure.bgms <- function(output, ...) {
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
+  
   
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
@@ -367,6 +407,7 @@ plot_structure.bgms <- function(output, ...) {
   
   output <- res
   
+  
   # Specify default arguments for function
   default_args <- list(
     layout = qgraph::averageLayout(as.matrix(output$parameters*output$structure)),
@@ -399,15 +440,21 @@ plot_structure.bgms <- function(output, ...) {
 
 plot_parameterHDI.bgms <- function(output, ...) {
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
   
   if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
   }
+  
+  
+  
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = FALSE,
                                   type = NULL, not_cont = NULL, data = NULL,
                                   edge_prior = fit_args$edge_prior,
@@ -470,18 +517,22 @@ plot_parameterHDI.bgms <- function(output, ...) {
 
 #' @export
 
-plot_centrality.bgms <- function(output, ...){
+plot_centrality.bgms <- function(output, group_names = NULL, ...){
   
-  if(packageVersion("bgms") < "0.1.3"){
+  if(packageVersion("bgms") < "0.1.4"){
     stop("Your version of the package bgms is not supported anymore. Please update.")
   }
   
   fit_args <- bgms::extract_arguments(output)
+  if(packageVersion("bgms") > "0.1.4.2"){
+    fit_args$save <- TRUE
+  }
   
   if(!fit_args$save){
     stop("Samples of the posterior distribution required. When estimating the model with bgm, set \"save = TRUE\".")
   }
   
+  
   res <- bgm_extract.package_bgms(fit = output, save = fit_args$save, centrality = TRUE,
                                   type = NULL, not_cont = NULL, data = NULL,
                                   edge_prior = fit_args$edge_prior,
@@ -529,10 +580,12 @@ plot_centrality.bgms <- function(output, ...){
                                    lower = centrality_hdi[1, ],
                                    upper = centrality_hdi[2, ])
   
-  centrality_summary |>
-    dplyr::arrange(mean) |>
-    dplyr::mutate(node = factor(.data$node, levels = .data$node)) |>
-    ggplot(aes(x = .data$node, y=.data$mean, ...))+
+  centrality_summary <- dplyr::arrange(centrality_summary, mean)
+  centrality_summary <- dplyr::mutate(centrality_summary,
+                                      node = factor(.data$node, levels = .data$node)
+  )
+  
+  ggplot(centrality_summary, aes(x = .data$node, y=.data$mean, ...))+
     args$theme_ +
     geom_point()+
     args$geom_errorbar+
